# Python Senziio

Support libraries for the Senziio Theia device integration with Home Assistant.

[![python](https://img.shields.io/badge/Python-3.10%20%7C%203.11%20%7C%203.12-3776AB.svg?style=flat&logo=python&logoColor=white)](https://www.python.org)
[![License](https://img.shields.io/badge/License-Apache_2.0-green.svg?logo=apache)](http://www.apache.org/licenses/LICENSE-2.0)
